Re: [cmake-developers] Using cmake pkg-config-like in non-cmake builds

2010-11-23 Thread Alexander Neundorf
On Monday 22 November 2010, Alan W. Irwin wrote:
 On 2010-11-22 21:55+0100 Alexander Neundorf wrote:
  Hi,
 
  there can be the case that a package which has been built with cmake,
  should be used in a project which doesn't use cmake.
  There is a feature request that cmake should help with generating
  pkg-config pc-files: http://public.kitware.com/Bug/view.php?id=11446
 
  I don't like that idea, because a) this means duplicating information,
  and b) doing that in a less powerful format.
 
  I have a slightly different idea: instead of having cmake generate
  pc-files, modify/extend cmake so that it can be used similar to
  pkg-config by projects which don't use cmake as their buildsystem.
  I attached a first very quick try to that bug report.
  It's a small cmake script which can be executed by cmake with -P, and
  which basically contains one find_package() call and prints the results,
  so they can be fed into a compiler invocation in a makefile.
 
  It already somewhat works:
  $ cmake -DMODE=COMPILE -DCOMPILER_ID=GNU -DPACKAGE=PNG -P
  cmake-config.cmake -I/usr/include -I/usr/include
 
  $ cmake -DMODE=LINK -DCOMPILER_ID=GNU -DPACKAGE=PNG -P cmake-config.cmake
  /usr/lib/libpng.so /usr/lib/libz.so
 
 
  Do you think this makes sense ?

 Hi Alex:

 How did you collect that compiler flag information? 

I simply concatenated the include directories found in ${FOO_INCLUDE_DIRS}.
The script is attached to the bug report.

 As far as I know
 the command install(EXPORT ) only writes out information about
 the link flags but not the compile flags associated with a given
 library target. If your method of obtaining compile flag information
 is general enough, then it should be straightforward to modifiy that
 install signature to write out the compile flags as well, and that
 would be a huge win.

 For example, PLplot currently uses install(EXPORT ) to collect
 link flag information for all its libraries for the use of external
 projects.  And we use that information for an external CMake-based
 build system we have implemented to build and exhaustively test our
 installed examples. That build system would be a lot less cumbersome
 if we had access to compile flags for each of our libraries through
 the EXPORTed cmake file.

You can write any information you want into the install Config-file.
What I usually do is to configure() the Config-file, and that Config-file then 
include()s the exports-file.

Alex
___
cmake-developers mailing list
cmake-developers@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-developers


Re: [cmake-developers] User vs CMake include mismatch handling

2010-11-23 Thread Alexander Neundorf
On Monday 22 November 2010, Brad King wrote:
 On 11/22/2010 04:06 PM, Alexander Neundorf wrote:
  On Monday 22 November 2010, Brad King wrote:
...
  I think the path forward here is:
 
  (1) Improve documentation of CMAKE_USER_MAKE_RULES_OVERRIDE[_C]
  variables 
  (2) Add the Custom-* file inclusion, document it
 
  Do you think both (1) and (2) are necessary ?

 I suppose just (1) is enough.  It can be used to implement (2) in
 a given project.

Could you take care of (1) ?

Do you have anything special in mind with (2) or simply that users can set (1) 
to whatever they want ?

Alex
___
cmake-developers mailing list
cmake-developers@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-developers


Re: [cmake-developers] User vs CMake include mismatch handling

2010-11-23 Thread Brad King
On 11/23/2010 03:31 PM, Alexander Neundorf wrote:
 On Monday 22 November 2010, Brad King wrote:
 On 11/22/2010 04:06 PM, Alexander Neundorf wrote:
 On Monday 22 November 2010, Brad King wrote:
 (1) Improve documentation of CMAKE_USER_MAKE_RULES_OVERRIDE[_C] variables 
 (2) Add the Custom-* file inclusion, document it
 
 Could you take care of (1) ?

Sure, but not until at least next week.  The changes don't need to be done
in this order anyway.

 Do you have anything special in mind with (2) or simply that users can set 
 (1) 
 to whatever they want ?

I was just thinking that the script specified by (1) can contain code similar
to that in CMake*Information.cmake to load Custom-os-id-lang files.
If the custom info file code were added to CMake*Information.cmake it would
be just before scripts from (1) are included anyway.

-Brad
___
cmake-developers mailing list
cmake-developers@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-developers


Re: [cmake-developers] User vs CMake include mismatch handling

2010-11-23 Thread Alexander Neundorf
On Tuesday 23 November 2010, Brad King wrote:
 On 11/23/2010 03:31 PM, Alexander Neundorf wrote:
  On Monday 22 November 2010, Brad King wrote:
  On 11/22/2010 04:06 PM, Alexander Neundorf wrote:
  On Monday 22 November 2010, Brad King wrote:
  (1) Improve documentation of CMAKE_USER_MAKE_RULES_OVERRIDE[_C]
  variables (2) Add the Custom-* file inclusion, document it
 
  Could you take care of (1) ?

 Sure, but not until at least next week.  The changes don't need to be done
 in this order anyway.

Ok :-)
I'll start with the CMAKE_POLICY_DEFAULT_CMP stuff you suggested.

Alex
___
cmake-developers mailing list
cmake-developers@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-developers


[CMake] set_source_files_properties for include directories

2010-11-23 Thread Andrea Galeazzi
In a project I've got two groups of files having different include 
paths. These paths have some conflicts so I need to specify just one  
for each file requires it.
My first idea was to apply set_source_files_properties with a property 
like include_directories but I don't find anything similar. My next 
attempt is gonna use the COMPILE_FLAGS property, does anybody know a 
more efficient and elegant way to accomplish a such task?
An equivalent issue was discussed in this thread 
http://www.mail-archive.com/cmake@cmake.org/msg05276.html but I didn't 
find any useful answer.

___
Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


Re: [CMake] cmake 2.8.3 forces -rdynamic for pf90 in pure fortran projects

2010-11-23 Thread Verweij, Arjen
Hi Brad,

Please try the patch below.

It gets rid of -rdynamic for pure F90. I will try in a C/C++/F77/F90 project 
soonish (hopefully today). I didn't check if other flags get cleared as well.

Thanks,
Arjen

diff --git a/Modules/Platform/Linux-PGI.cmake b/Modules/Platform/Linux-
PGI.cmake
index ef06acd..43e0232 100644
--- a/Modules/Platform/Linux-PGI.cmake
+++ b/Modules/Platform/Linux-PGI.cmake
@@ -22,4 +22,5 @@ macro(__linux_compiler_pgi lang)
   # Shared library compile and link flags.
   set(CMAKE_SHARED_LIBRARY_${lang}_FLAGS -fPIC)
   set(CMAKE_SHARED_LIBRARY_CREATE_${lang}_FLAGS -shared)
+  set(CMAKE_SHARED_LIBRARY_LINK_${lang}_FLAGS )
 endmacro()
___
Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


[CMake] [PackageMaker] Install location customization

2010-11-23 Thread Domagoj Saric

Hi,
Is there any way to:
- disable the destination selection/customization altogether (both the 
Change Install Location option and the respective page and the Choose 
Folder... option one gets to if one clicks on Change Install Location)
- disable the Choose Folder... option even though the Change Install 
Location still exists...i.e. to allow changing of the target drive but not 
the folder (hierarchy)

or
- (for non-monolithic/.mpkg packages) to allow full customization (both at 
CMake/CPack-time and at runtime/installation-time) of the target location(s) 
and folder hierarchy...i.e. to allow per component (independent) selection 
of the target folder (including disabling the customization for some 
components and allowing it for others)... This is what you get through the 
Choice/Destination, Choice/Allow alternate volume and 
Package/Configuration/Allow custom location options in the Apple's 
PackageMaker application...


To reiterate, I have an application which has two components, one of which 
must go strictly to a predesignated folder (the user must not be allowed to 
change it) and the other component's install location can (but does not 
necessarily need to be) changed... For this to work properly, CPack must, at 
the very minimum, allow disabling of the install location customization 
altogether or, better, allow 
proper/full/'uncluttered-with-typical-hardcoded-choices' customization...


I apologize if there is an obvious/documented way of doing this but I was 
unable to find it even after days of struggling with this issue...I even 
went searching for undocumented options/variables through the CPack 
binary...

set( CPACK_PACKAGE_RELOCATABLE ON ) did not help...

(using CMake 2.8.3)


ps. even though I set/use no installation type(s), the Installer 'sidebar' 
still shows Installation type...


pps. the 'application' in question is actually a VST plugin (similar to an 
AU component) for which CMake/CPack are additionally bugged by more/other 
hardcoded choices...for example a VST plugin is a bundle with a .vst 
extension making it impossible to use the install( TARGETS ... BUNDLE ) 
command because BUNDLE support is (AFAICT) hardcoded to use the .app 
extension...



-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v2.8.3-704-ge7f6e52

2010-11-23 Thread Clinton Stimpson
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  e7f6e52aace65c84499c49a59d370b5069cca70d (commit)
   via  28c1be7a504c45d1a030c2d982a03b4e1cf7251b (commit)
  from  5b1b47d703f88d8a65aab4a1a196b727b9eb0f67 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=e7f6e52aace65c84499c49a59d370b5069cca70d
commit e7f6e52aace65c84499c49a59d370b5069cca70d
Merge: 5b1b47d 28c1be7
Author: Clinton Stimpson clin...@elemtech.com
AuthorDate: Tue Nov 23 18:06:38 2010 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Tue Nov 23 18:06:38 2010 -0500

Merge topic 'bundleutils-rpath-removal' into next

28c1be7 BundleUtilities: only do rpath strip on copied prerequisites.


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=28c1be7a504c45d1a030c2d982a03b4e1cf7251b
commit 28c1be7a504c45d1a030c2d982a03b4e1cf7251b
Author: Clinton Stimpson clin...@elemtech.com
AuthorDate: Tue Nov 23 14:29:46 2010 -0700
Commit: Clinton Stimpson clin...@elemtech.com
CommitDate: Tue Nov 23 14:29:46 2010 -0700

BundleUtilities: only do rpath strip on copied prerequisites.

diff --git a/Modules/BundleUtilities.cmake b/Modules/BundleUtilities.cmake
index c7ead5b..48830cb 100644
--- a/Modules/BundleUtilities.cmake
+++ b/Modules/BundleUtilities.cmake
@@ -472,11 +472,11 @@ function(copy_resolved_item_into_bundle resolved_item 
resolved_embedded_item)
   else()
 #message(STATUS copying COMMAND ${CMAKE_COMMAND} -E copy ${resolved_item} 
${resolved_embedded_item})
 execute_process(COMMAND ${CMAKE_COMMAND} -E copy ${resolved_item} 
${resolved_embedded_item})
+if(UNIX AND NOT APPLE)
+  file(RPATH_REMOVE FILE ${resolved_embedded_item})
+endif(UNIX AND NOT APPLE)
   endif()
 
-  if(UNIX AND NOT APPLE)
-file(RPATH_REMOVE FILE ${resolved_embedded_item})
-  endif(UNIX AND NOT APPLE)
 endfunction(copy_resolved_item_into_bundle)
 
 
@@ -514,11 +514,11 @@ function(copy_resolved_framework_into_bundle 
resolved_item resolved_embedded_ite
 execute_process(COMMAND ${CMAKE_COMMAND} -E copy_directory 
${resolved_resources} ${resolved_embedded_resources})
   endif()
 endif()
+if(UNIX AND NOT APPLE)
+  file(RPATH_REMOVE FILE ${resolved_embedded_item})
+endif(UNIX AND NOT APPLE)
   endif()
 
-  if(UNIX AND NOT APPLE)
-file(RPATH_REMOVE FILE ${resolved_embedded_item})
-  endif(UNIX AND NOT APPLE)
 endfunction(copy_resolved_framework_into_bundle)
 
 

---

Summary of changes:
 Modules/BundleUtilities.cmake |   12 ++--
 1 files changed, 6 insertions(+), 6 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v2.8.3-131-g8bafdeb

2010-11-23 Thread KWSys Robot
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, master has been updated
   via  8bafdeb60edcb2c1f7b1fd8e18213129ccdf085a (commit)
  from  5b00b2a2018cfd3fdb52185e8c4852dc0c50fc89 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=8bafdeb60edcb2c1f7b1fd8e18213129ccdf085a
commit 8bafdeb60edcb2c1f7b1fd8e18213129ccdf085a
Author: KWSys Robot kwro...@kitware.com
AuthorDate: Wed Nov 24 00:01:04 2010 -0500
Commit: KWSys Robot kwro...@kitware.com
CommitDate: Wed Nov 24 00:10:03 2010 -0500

KWSys Nightly Date Stamp

diff --git a/Source/kwsys/kwsysDateStamp.cmake 
b/Source/kwsys/kwsysDateStamp.cmake
index 92aa88f..8fddfe7 100644
--- a/Source/kwsys/kwsysDateStamp.cmake
+++ b/Source/kwsys/kwsysDateStamp.cmake
@@ -18,4 +18,4 @@ SET(KWSYS_DATE_STAMP_YEAR  2010)
 SET(KWSYS_DATE_STAMP_MONTH 11)
 
 # KWSys version date day component.  Format is DD.
-SET(KWSYS_DATE_STAMP_DAY   23)
+SET(KWSYS_DATE_STAMP_DAY   24)

---

Summary of changes:
 Source/kwsys/kwsysDateStamp.cmake |2 +-
 1 files changed, 1 insertions(+), 1 deletions(-)


hooks/post-receive
--
What Huxley teaches is that in the age of advanced technology, spiritual
devastation is more likely to come from an enemy with a smiling face than
from one whose countenance exudes suspicion and hate.
Neil Postman 


___
Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


Re: [CMake] providing library information, what's the cmake way

2010-11-23 Thread Johannes Zarl
Sorry for hijacking this thread, but I'm wondering about this for some 
time, too. (And the information in the doc/wiki is somewhat dated and/or 
ambiguous [1,2,3,4]). I will just go on and write my thoughts and what I 
(think I) know, in the hope that somebody corrects those things I got 
wrong.

So summarizing the previous mesage in the thread, one can say:
 + cmake aware packages should provide LibraryConfig.cmake scripts
   (and optionally LibraryVersion.cmake scrips), just like they would
   provide pkg-config files.
 + developers should create FindLibrary.cmake scripts for packages
   they are using that are not cmake aware.

I think that information should be transported more clearly, because
in practice most cmake based software provides a FindLibrary.cmake
file for itself.

Also, I could not find a definitive answer on where these packages 
should put the LibraryConfig.cmake script. If I read the search paths in
[1] correctly, the preferred paths are:
 + prefix/ on windows
 + prefix/(share|lib)/cmake/name*/ on linux, and
 + prefix/name.framework/Resources/ on Apple

We have have every library and library-version in its own prefix and use 
shell modules[5] to provide the correct environment that a user wants.
Is there any way to let cmake know about specific prefix directories it 
should be aware of? Unfortunately, the CMAKE_MODULE_PATH variable has
to be manually set, and not influenced by the environment.

Something like the PKG_CONFIG_PATH environment variable for pkg-config
would be really nice to have in cmake.

Another somehow related topic seems to be import/export of targets. Should
a LibraryConfig.cmake or FindLibrary.cmake file create imported targets
for the library?

And is there any documentation on how to create a LibraryConfig.cmake file
with support for components?

Cheers,
  Johannes

[1] http://www.cmake.org/cmake/help/cmake-2-8-docs.html#command:find_package
[2] http://www.cmake.org/Wiki/CMake_HowToFindInstalledSoftware
[3] http://www.cmake.org/Wiki/CMake:How_To_Find_Libraries
[4] http://www.cmake.org/Wiki/CMake:Improving_Find*_Modules
[5] http://modules.sourceforge.net/




-- 
Johannes Zarl
Virtual Reality Services

Johannes Kepler University
Informationsmanagement

Altenbergerstrasze 69
4040 Linz, Austria
Phone: +43 732 2468-8321
johannes.z...@jku.at
http://vrc.zid.jku.at










___
Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


Re: [CMake] set_source_files_properties for include directories

2010-11-23 Thread Marcel Loose
 On 23-11-2010 at 10:55, in message 4ceb8f76.80...@korg.it, Andrea
Galeazzi
galea...@korg.it wrote: 
 In a project I've got two groups of files having different include 
 paths. These paths have some conflicts so I need to specify just one 

 for each file requires it.
 My first idea was to apply set_source_files_properties with a
property 
 like include_directories but I don't find anything similar. My next 
 attempt is gonna use the COMPILE_FLAGS property, does anybody know a

 more efficient and elegant way to accomplish a such task?
 An equivalent issue was discussed in this thread 
 http://www.mail-archive.com/cmake@cmake.org/msg05276.html but I
didn't 
 find any useful answer.
 ___
 Powered by www.kitware.com
 
 Visit other Kitware open-source projects at 
 http://www.kitware.com/opensource/opensource.html
 
 Please keep messages on-topic and check the CMake FAQ at: 
 http://www.cmake.org/Wiki/CMake_FAQ
 
 Follow this link to subscribe/unsubscribe:
 http://www.cmake.org/mailman/listinfo/cmake

Hi Andrea,

As you noted include_directories is a per-directory setting. So, if
you're free to reorganize your source files, you could put the two
groups of files in two different directories. Then you can use
include_directories() in each directory. Make sure you don't make one of
these directories a subdirectory of the other.

HTH,
Marcel Loose.

___
Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


[CMake] CMake adds lib prefix to library. Bug?

2010-11-23 Thread Adam J Richardson
Hi list.

Not sure if this is a bug or something stupid I've done. On several
Windows build environments (two XP, two 7, this happens with 2.8.2 and
2.8.3), I'm getting the error:

c:/compilers/mingw/bin/../lib/gcc/mingw32/4.4.1/../../../../mingw32/bin/ld.exe: 
cannot find -llibodbc32

That's clear enough. It's also clear what the problem is: there is no
liblibodbc32.a in my environment. There is however a libodbc32.a, which
I would expect it to pick up.

With VERBOSE=1, make gives me a long g++ command ending with:

... -Wl,-Bstatic -llibodbc32 -Wl,-Bdynamic -lkernel32 -luser32 -lgdi32
-lwinspool -lshell32 -lole32 -loleaut32 -luuid -lcomdlg32 -ladvapi32

Which is correct apart from the -llibodbc32 part. (I'm not entirely
clear on why CMake felt it necessary to specify that it's a static lib
when it didn't with the previous ones.)

I've debugged my FindODBC.cmake with message(STATUS ${blah})
instructions and it returns odbc32, which is correct.

So my question is: why is CMake adding an extra lib? I can work
around it for now, but I'd like to solve this one properly.

Thanks,
Adam J Richardson



CMakeLists.txt snippet:

if (ODBC_FOUND)
   set(T_LIBS ${T_LIBS} ${ODBC_LIBRARIES})
#   message(STATUS ODBC: ${ODBC_LIBRARIES})
else()
   set(CMAKE_CXX_FLAGS ${CMAKE_CXX_FLAGS} -DNO_ODBC=1)
   message(STATUS ODBC not found, omitting from build.)
endif()

FindODBC.cmake sans comments:

SET( ODBC_FOUND 0 )
FIND_PATH(ODBC_INCLUDE_DIRECTORIES sql.h
  DOC Specify the directory containing sql.h.
)
FIND_LIBRARY( ODBC_LIBRARIES 
  NAMES iodbc odbc odbcinst odbc32
  DOC Specify the ODBC driver manager library here.
)
IF (ODBC_LIBRARIES)
  IF (ODBC_INCLUDE_DIRECTORIES)
SET( ODBC_FOUND 1 )
  ENDIF (ODBC_INCLUDE_DIRECTORIES)
ENDIF (ODBC_LIBRARIES)
MARK_AS_ADVANCED( ODBC_FOUND ODBC_LIBRARY ODBC_LIBRARIES ODBC_EXTRA_LIBRARIES 
ODBC_INCLUDE_DIRECTORIES )


signature.asc
Description: PGP signature
___
Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake

[CMake] set CMAKE_INSTALL_PREFIX in CMakeLists

2010-11-23 Thread tomasoni
Dear Cmake users,

1) I am trying to set CMAKE_INSTALL_PREFIX in the CMakeLists file with
SET(CMAKE_INSTALL_PREFIX, my/path)
but the variable remain unset; everything works fine if the variable is
set on the command line when invoking cmake
(-DCMAKE_INSTALL_PREFIX=my/path).

2) I am also looking for a way to avoid having to invoke cmake -GEclipse
CDT4 - Unix Makefiles option. Can I set it in the CMakeLists?

Trying to avoid my users some typing...

Thank you as usual,
Mattia
___
Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


Re: [CMake] CMake adds lib prefix to library. Bug?

2010-11-23 Thread Rolf Eike Beer
 Hi list.

 Not sure if this is a bug or something stupid I've done. On several
 Windows build environments (two XP, two 7, this happens with 2.8.2 and
 2.8.3), I'm getting the error:

 c:/compilers/mingw/bin/../lib/gcc/mingw32/4.4.1/../../../../mingw32/bin/ld.exe:
 cannot find -llibodbc32

 That's clear enough. It's also clear what the problem is: there is no
 liblibodbc32.a in my environment. There is however a libodbc32.a, which
 I would expect it to pick up.

 With VERBOSE=1, make gives me a long g++ command ending with:

 ... -Wl,-Bstatic -llibodbc32 -Wl,-Bdynamic -lkernel32 -luser32 -lgdi32
 -lwinspool -lshell32 -lole32 -loleaut32 -luuid -lcomdlg32 -ladvapi32

 Which is correct apart from the -llibodbc32 part. (I'm not entirely
 clear on why CMake felt it necessary to specify that it's a static lib
 when it didn't with the previous ones.)

 I've debugged my FindODBC.cmake with message(STATUS ${blah})
 instructions and it returns odbc32, which is correct.

 So my question is: why is CMake adding an extra lib? I can work
 around it for now, but I'd like to solve this one properly.

http://public.kitware.com/Bug/view.php?id=11468

Eike
___
Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


Re: [CMake] set CMAKE_INSTALL_PREFIX in CMakeLists

2010-11-23 Thread Micha Renner
Am Dienstag, den 23.11.2010, 14:01 +0100 schrieb tomas...@sbc.su.se:
 Dear Cmake users,
 
 1) I am trying to set CMAKE_INSTALL_PREFIX in the CMakeLists file with
 SET(CMAKE_INSTALL_PREFIX, my/path)
 ^
 No comma!

greetings
Micha


___
Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


Re: [CMake] set CMAKE_INSTALL_PREFIX in CMakeLists

2010-11-23 Thread Michael Wild
On 11/23/2010 02:33 PM, Micha Renner wrote:
 Am Dienstag, den 23.11.2010, 14:01 +0100 schrieb tomas...@sbc.su.se:
 Dear Cmake users,

 1) I am trying to set CMAKE_INSTALL_PREFIX in the CMakeLists file with
 SET(CMAKE_INSTALL_PREFIX, my/path)
  ^
  No comma!
 
 greetings
 Micha

And *NEVER EVER* set CMAKE_INSTALL_PREFIX in your CMakeLists.txt file.
That is a user-setting and you will make people angry at you if you
override their choice in your code.

Michael

___
Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


Re: [CMake] set_source_files_properties for includedirectories

2010-11-23 Thread Andrea Galeazzi

Marcel Loose ha scritto:

On 23-11-2010 at 10:55, in message 4ceb8f76.80...@korg.it, Andrea


Galeazzi
galea...@korg.it wrote: 
  
In a project I've got two groups of files having different include 
paths. These paths have some conflicts so I need to specify just one 



  

for each file requires it.
My first idea was to apply set_source_files_properties with a

property 
  
like include_directories but I don't find anything similar. My next 
attempt is gonna use the COMPILE_FLAGS property, does anybody know a



  

more efficient and elegant way to accomplish a such task?
An equivalent issue was discussed in this thread 
http://www.mail-archive.com/cmake@cmake.org/msg05276.html but I

didn't 
  

find any useful answer.
___
Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html


Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ


Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake



Hi Andrea,

As you noted include_directories is a per-directory setting. So, if
you're free to reorganize your source files, you could put the two
groups of files in two different directories. Then you can use
include_directories() in each directory. Make sure you don't make one of
these directories a subdirectory of the other.

HTH,
Marcel Loose.


__ Informazioni da ESET NOD32 Antivirus, versione del database delle 
firme digitali 5639 (20101122) __

Il messaggio è stato controllato da ESET NOD32 Antivirus.

www.nod32.it




  
Yes, the sources are splitted in different directories but the 
CMakeLists.txt is just one:

-Root
 CMakeLists.txt
 -dir1
   file1.cpp
   file2.cpp
   ..
 -dir2
file1.cpp
file2.cpp
.
I'd like to generate just one IDE project from this project.
___
Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


Re: [CMake] set CMAKE_INSTALL_PREFIX in CMakeLists

2010-11-23 Thread Micha Renner
Am Dienstag, den 23.11.2010, 15:01 +0100 schrieb Michael Wild:
 On 11/23/2010 02:33 PM, Micha Renner wrote:
  Am Dienstag, den 23.11.2010, 14:01 +0100 schrieb tomas...@sbc.su.se:
  Dear Cmake users,
 
  1) I am trying to set CMAKE_INSTALL_PREFIX in the CMakeLists file with
  SET(CMAKE_INSTALL_PREFIX, my/path)
   ^
   No comma!
  
  greetings
  Micha
 
 And *NEVER EVER* set CMAKE_INSTALL_PREFIX in your CMakeLists.txt file.
 That is a user-setting and you will make people angry at you if you
 override their choice in your code.

Okay, then this might help:

IF(CMAKE_INSTALL_PREFIX_INITIALIZED_TO_DEFAULT)
SET(CMAKE_INSTALL_PREFIX /usr/local CACHE PATH Foo install
 prefix FORCE)
ENDIF(CMAKE_INSTALL_PREFIX_INITIALIZED_TO_DEFAULT)

Of course, this is not my idea. It had someone from kitware, I don't
remember who it was.


greetings
Micha



___
Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


Re: [CMake] providing library information, what's the cmake way

2010-11-23 Thread Ian Monroe
On Mon, Nov 22, 2010 at 10:37 PM, Michael Hertling mhertl...@online.de wrote:
[snip]
 This seems like a common situation,  so I'm wondering what the common
 solution is.

 'hope that helps.

Thanks, yes that helps a lot. I figured there must be some method like this.

@Johannes Zarl: hijack away, I'm also interested in your questions. :)

Ian
___
Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


[CMake] How to rerun cmake if a file changes

2010-11-23 Thread Vladislav Vaintroub
Hello,
we use a text file as input for out build to store version info.  The
content of this file is
./VERSION:

MYSQL_VERSION_MAJOR=5
MYSQL_VERSION_MINOR=5
MYSQL_VERSION_PATCH=8
MYSQL_VERSION_EXTRA=

During cmake run, the information is extracted, parsed,
CPACK_PACKAGE_FILE_NAME is generated,  and some other things happen, e.g we
configure a header file mysql_version.h. 
So far, it works nicely, the only problem  with it is that cmake is not
rerun when this file changes. I made an attempt to fix it by introducing
custom command and custom target

ADD_CUSTOM_COMMAND(
   OUTPUT  ${CMAKE_BINARY_DIR}/VERSION.dep
   COMMAND ${CMAKE_COMMAND} ${CMAKE_BINARY_DIR}
   COMMAND ${CMAKE_COMMAND} -E touch ${CMAKE_BINARY_DIR}/VERSION.dep
   DEPENDS ${CMAKE_SOURCE_DIR}/VERSION
   )
ADD_CUSTOM_TARGET(check_version ALL DEPENDS ${CMAKE_BINARY_DIR}/VERSION.dep)

This seems to work but is not without problems. For example the very first
build with rerun cmake to generate VERSION.dep.  It takes some seconds with
Makefiles,  this is not a big problem, however in Visual Studio (I'm using
VS2010) the very first build would tell me N  solutions regenerated, you
want to rebuild?, and then  I clicking OK a COM error would popup (the
build would actually still continue run successfully despite popups and COM
error).

So the question is if there is a nicer way to accomplish what I want to do.
I'm aware that if VERSION had CMake syntax with SET(MYSQL_MAJOR_VERSION 5)
etc, then I could just INCLUDE this file, and this would fix  problems I
have.  I'm however more interested in a solution that would not force that
file to be written in CMake syntax. 

Thanks,
Vladislav

___
Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


Re: [CMake] How to rerun cmake if a file changes

2010-11-23 Thread Eric Noulard
2010/11/23 Vladislav Vaintroub vvaintr...@googlemail.com:
 Hello,
 we use a text file as input for out build to store version info.  The
 content of this file is
 ./VERSION:

 MYSQL_VERSION_MAJOR=5
 MYSQL_VERSION_MINOR=5
 MYSQL_VERSION_PATCH=8
 MYSQL_VERSION_EXTRA=

 During cmake run, the information is extracted, parsed,
 CPACK_PACKAGE_FILE_NAME is generated,  and some other things happen, e.g we
 configure a header file mysql_version.h.
 So far, it works nicely, the only problem  with it is that cmake is not
 rerun when this file changes. I made an attempt to fix it by introducing
 custom command and custom target

 ADD_CUSTOM_COMMAND(
   OUTPUT  ${CMAKE_BINARY_DIR}/VERSION.dep
   COMMAND ${CMAKE_COMMAND} ${CMAKE_BINARY_DIR}
   COMMAND ${CMAKE_COMMAND} -E touch ${CMAKE_BINARY_DIR}/VERSION.dep
   DEPENDS ${CMAKE_SOURCE_DIR}/VERSION
   )
 ADD_CUSTOM_TARGET(check_version ALL DEPENDS ${CMAKE_BINARY_DIR}/VERSION.dep)

 This seems to work but is not without problems. For example the very first
 build with rerun cmake to generate VERSION.dep.  It takes some seconds with
 Makefiles,  this is not a big problem, however in Visual Studio (I'm using
 VS2010) the very first build would tell me N  solutions regenerated, you
 want to rebuild?, and then  I clicking OK a COM error would popup (the
 build would actually still continue run successfully despite popups and COM
 error).

 So the question is if there is a nicer way to accomplish what I want to do.
 I'm aware that if VERSION had CMake syntax with SET(MYSQL_MAJOR_VERSION 5)
 etc, then I could just INCLUDE this file, and this would fix  problems I
 have.  I'm however more interested in a solution that would not force that
 file to be written in CMake syntax.

Do you want to preserve  the content of the file or you don't want
to write MYSQL_VERSION_xxx in CMake syntax?

If you only want to preserve this particular file you could generate
it file from your main CMakeLists.txt if you add
version definition in CMakeLists.txt:

SET(MYSQL_VERSION_MAJOR 5)
SET(MYSQL_VERSION_MINOR 5)
SET(MYSQL_VERSION_PATCH 8)
SET(MYSQL_VERSION_EXTRA )

some VERSION.in file contains;
mysql_version_maj...@mysql_major_version@
mysql_version_min...@mysql_version_minor@
mysql_version_pat...@mysql_version_patch@
mysql_version_ext...@mysql_version_extra@


configure_file(${CMAKE_SOURCE_DIR}/VERSION.in
${CMAKE_BINARY_DIR}/VERSION}
@ONLY)

if VERSION file has to be in source tree (would be better to avoid that):

configure_file(${CMAKE_SOURCE_DIR}/VERSION.in
${CMAKE_SOURCE_DIR}/VERSION}
@ONLY)

If you don't want that you should already be generating
mysql_version.h using this file and may be some custom command/target
and I bet the rest of the build depends on mysql_version.h?

So may be your custom command used to generate mysql_version.h
is lacking a file dep?

By the way I cannot find any VERSION file on a fresh update of lp:mysql-server ?

-- 
Erk
Membre de l'April - « promouvoir et défendre le logiciel libre » -
http://www.april.org
___
Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


[CMake] Visual Studio 2008 and 2010 RUNTIME_OUTPUT_DIRECTORY doesn't work

2010-11-23 Thread Aaron R
I'm trying to get my dlls and exes to output in a speicfic directory,
regardless of build type.

I should be able to do this using:

set(CMAKE_RUNTIME_OUTPUT_DIRECTORY ${CMAKE_SOURCE_DIR}/bin )

I still end up with

(top dirs)/bin/Debug/myapp.exe
(top dirs)/bin/Release/myapp.exe

According to these tickets:

http://www.vtk.org/Bug/view.php?id=10276
http://www.vtk.org/Bug/view.php?id=9163

It should work, as 9163 went into the master for cmake 2.8.1.RC1.  I'm using
2.8.3.  I had the same behavior for 2.8.2.

VS2008 will work if I use the 'prefix hack'.  This does not work under
VS2010 though.

set_target_properties(myApp PROPERTIES PREFIX ../ RUNTIME_OUTPUT_DIRECTORY
${CMAKE_SOURCE_DIR}/bin)

Am I confused?  What's the correct way to make this work?  Was it fixed and
then broke again?

Thanks,
Aaron
___
Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake

Re: [CMake] set CMAKE_INSTALL_PREFIX in CMakeLists

2010-11-23 Thread Alexander Neundorf
On Tuesday 23 November 2010, tomas...@sbc.su.se wrote:
 Dear Cmake users,

 1) I am trying to set CMAKE_INSTALL_PREFIX in the CMakeLists file with
 SET(CMAKE_INSTALL_PREFIX, my/path)
 but the variable remain unset; everything works fine if the variable is
 set on the command line when invoking cmake
 (-DCMAKE_INSTALL_PREFIX=my/path).

 2) I am also looking for a way to avoid having to invoke cmake -GEclipse
 CDT4 - Unix Makefiles option. Can I set it in the CMakeLists?

If you use cmake-gui (instead of cmake, which may be a good idea if the users 
don't like typing that much), they are asked to select this from a combobox, 
and on later runs their previous choice is the default selection there.

Alex
___
Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


Re: [CMake] How to rerun cmake if a file changes

2010-11-23 Thread Vladislav Vaintroub


 -Original Message-
 From: Eric Noulard [mailto:eric.noul...@gmail.com]
 Sent: Dienstag, 23. November 2010 21:07
 To: Vladislav Vaintroub
 Cc: cmake@cmake.org
 Subject: Re: [CMake] How to rerun cmake if a file changes
 
 2010/11/23 Vladislav Vaintroub vvaintr...@googlemail.com:
  Hello,
  we use a text file as input for out build to store version info.  The
  content of this file is
  ./VERSION:
 
  MYSQL_VERSION_MAJOR=5
  MYSQL_VERSION_MINOR=5
  MYSQL_VERSION_PATCH=8
  MYSQL_VERSION_EXTRA=
 
  During cmake run, the information is extracted, parsed,
  CPACK_PACKAGE_FILE_NAME is generated,  and some other things
 happen,
  e.g we configure a header file mysql_version.h.
  So far, it works nicely, the only problem  with it is that cmake is
  not rerun when this file changes. I made an attempt to fix it by
  introducing custom command and custom target
 
  ADD_CUSTOM_COMMAND(
    OUTPUT  ${CMAKE_BINARY_DIR}/VERSION.dep
    COMMAND ${CMAKE_COMMAND} ${CMAKE_BINARY_DIR}
    COMMAND ${CMAKE_COMMAND} -E touch
 ${CMAKE_BINARY_DIR}/VERSION.dep
    DEPENDS ${CMAKE_SOURCE_DIR}/VERSION
    )
  ADD_CUSTOM_TARGET(check_version ALL DEPENDS
  ${CMAKE_BINARY_DIR}/VERSION.dep)
 
  This seems to work but is not without problems. For example the very
  first build with rerun cmake to generate VERSION.dep.  It takes some
  seconds with Makefiles,  this is not a big problem, however in Visual
  Studio (I'm using
  VS2010) the very first build would tell me N  solutions regenerated,
  you want to rebuild?, and then  I clicking OK a COM error would
  popup (the build would actually still continue run successfully
  despite popups and COM error).
 
  So the question is if there is a nicer way to accomplish what I want to
do.
  I'm aware that if VERSION had CMake syntax with
  SET(MYSQL_MAJOR_VERSION 5) etc, then I could just INCLUDE this file,
  and this would fix  problems I have.  I'm however more interested in a
  solution that would not force that file to be written in CMake syntax.

Hi Eric,
thanks for looking.

 Do you want to preserve  the content of the file or you don't want to
write
 MYSQL_VERSION_xxx in CMake syntax?

One of the  wishes now that autotools-based build system is gone completely,
was to be able to simply identify version ,e.g in with shell syntax
source ./VERSION 
(use MYSQL_VERSION_XXX in my favorite shell script)

Until recently, this was done with parsing   ./configure.in, even
CMake-based build would extract this info from some AC_INIT(...) to find out
the major, minor and patch version
 
 
 If you only want to preserve this particular file you could generate it
file from
 your main CMakeLists.txt if you add version definition in CMakeLists.txt:
 
 SET(MYSQL_VERSION_MAJOR 5)
 SET(MYSQL_VERSION_MINOR 5)
 SET(MYSQL_VERSION_PATCH 8)
 SET(MYSQL_VERSION_EXTRA )
 
 some VERSION.in file contains;
 mysql_version_maj...@mysql_major_version@
 mysql_version_min...@mysql_version_minor@
 mysql_version_pat...@mysql_version_patch@
 mysql_version_ext...@mysql_version_extra@
 
 
 configure_file(${CMAKE_SOURCE_DIR}/VERSION.in
 ${CMAKE_BINARY_DIR}/VERSION}
 @ONLY)
 
 if VERSION file has to be in source tree (would be better to avoid
that):
 
 configure_file(${CMAKE_SOURCE_DIR}/VERSION.in
 ${CMAKE_SOURCE_DIR}/VERSION}
 @ONLY)
 
 If you don't want that you should already be generating mysql_version.h
 using this file and may be some custom command/target and I bet the rest
of
 the build depends on mysql_version.h?

I understand the idea, and yes, it sounds like solution, though not for
exactly  my problem :) I would still prefer some way to do it without
generating VERSION, but considering it as build input instead.  Some people
would prefer to  run source ./VERSION prior to cmake, or perhaps without
cmake at all 

And I guess I found a way around it after some experimentation. It seems to
work If I do this for example
CONFIGURE_FILE(
  ${CMAKE_SOURCE _DIR}/VERSION 
  ${CMAKE_BINARY_DIR}/VERSION.junk
)

I'd never use output file VERSION.junk, but CONFIGURE_FILE alone seems to
have the desired side-effect, it will force cmake to rerun if  VERSION file
changes.

 So may be your custom command used to generate mysql_version.h is
 lacking a file dep?

For mysql_version.h , there was no dependency and no special target, it was
just parsing  ./VERSION (and, prior to that ./configure.in) and
CONFIGURE_FILE.  Yes, this lacked a dependency.  But simple custom target
would not solve our problems either, we do other things with version
numbers, generating CMAKE_PACKAGE_FILE_NAME for example. Changing this
variable would require rerunning cmake in my understanding

So far missing dependency this was never considered  important, as the
version numbers change rarely, and probability that something goes wrong is
very low. It worst case, rerun cmake per hand, et viola.  And our automated
builds would build everything from scratch anyway. While it 

[CMake] option, configure_file and ON/OFF

2010-11-23 Thread Anton Deguet
Hello,

I am trying to use a UI option to set a value used in configure_file and 
ideally obtain a file that doesn't use ON/OFF.   Here is a CMake sample:
  option (MYLIB_HAS_WHATEVER Use whatever library OFF)

In my config.h.in I have:
  #define ON 1
  #define OFF 0
  #define MYLIB_HAS_WHATEVER ${MYLIB_HAS_WHATEVER}

Then in my code I can use:
  #if MYLIB_HAS_WHATEVER
  
  #endif

It worked so far but there is an issue if we end up using other libraries which 
also define ON and/or OFF.  There seems to be no way to tell CMake to use 1/0 
instead of ON/OFF during the configure_file.  My solution has been to modify my 
CMake to do the following:
  option (MYLIB_HAS_WHATEVER Use whatever library OFF)
  if (MYLIB_HAS_WHATEVER)
set(MYLIB_CONFIG_HAS_WHATEVER 1)

  else (MYLIB_HAS_WHATEVER)
set(MYLIB_CONFIG_HAS_WHATEVER 0)

  endif (MYLIB_HAS_WHATEVER)

and in the config.h.in do:
  #define MYLIB_HAS_WHATEVER ${MYLIB_CONFIG_HAS_WHATEVER}

Is there a better way?

Anton

---
Anton Deguet, Research Engineer, ERC-CISST/LCSR, Johns Hopkins University
e-mail: anton.deg...@jhu.edu, iChat: anton.deg...@mac.com
phone: 410-790-0456
JHU, LCSR, Hackerman Hall 137b, 3400 North Charles Street, Baltimore, MD 21218, 
USA




___
Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


[CMake] test property COST not working in cmake 2.8.3?

2010-11-23 Thread Tyler Roscoe
I use set_tests_properties (... COST -500) to force my code coverage
checks to run after all the unit tests have run. This has stopped
working and I'm reasonably confident that the only thing that changed
was an upgrade from cmake 2.8.0 or 2.8.1 to 2.8.3.

I couldn't find anything in the bug tracker or in the release notes
suggesting that COST or test properties were changed in 2.8.3.

I'm still getting lines like this in my generated CTestTestfile.cmake:

SET_TESTS_PROPERTIES(rs_exerciser_2dgrid PROPERTIES  COST -500 
FAIL_REGULAR_EXPRESSION TP_EXERCISER_FAIL)

and the FAIL_REGULAR_EXPRESSION property seems to be working just fine.


I've included a small repro case below. This looks like a regression. Should I
open a bug?

Thanks,
tyler


[tyle...@tpb006:~/cmake-test-properties-test]$ cat CMakeLists.txt
cmake_minimum_required(VERSION 2.8)
project(p)
enable_testing()

add_test (i_should_run_second echo i should run second)
set_tests_properties (i_should_run_second PROPERTIES COST -1)
add_test (i_should_run_first echo i should run first)

[tyle...@tpb006:~/cmake-test-properties-test]$ mkdir b  cd b  cmake ..
-- The C compiler identification is GNU
-- The CXX compiler identification is GNU
-- Check for working C compiler: /usr/bin/gcc
-- Check for working C compiler: /usr/bin/gcc -- works
-- Detecting C compiler ABI info
-- Detecting C compiler ABI info - done
-- Check for working CXX compiler: /usr/bin/c++
-- Check for working CXX compiler: /usr/bin/c++ -- works
-- Detecting CXX compiler ABI info
-- Detecting CXX compiler ABI info - done
-- Configuring done
-- Generating done
-- Build files have been written to: 
/tpb006/tylermr/cmake-test-properties-test/b

[tyle...@tpb006:~/cmake-test-properties-test/b]$ ctest --version
ctest version 2.8.3
[tyle...@tpb006:~/cmake-test-properties-test/b]$ ctest
Test project /tpb006/tylermr/cmake-test-properties-test/b
Start 1: i_should_run_second
1/2 Test #1: i_should_run_second ..   Passed0.01 sec
Start 2: i_should_run_first
2/2 Test #2: i_should_run_first ...   Passed0.01 sec

100% tests passed, 0 tests failed out of 2

Total Test time (real) =   0.04 sec

[tyle...@tpb006:~/cmake-test-properties-test/b]$ 
/usr/local/cmake-2.8.1-Linux-i386/bin/ctest --version
ctest version 2.8.1
[tyle...@tpb006:~/cmake-test-properties-test/b]$ 
/usr/local/cmake-2.8.1-Linux-i386/bin/ctest
Test project /tpb006/tylermr/cmake-test-properties-test/b
Start 2: i_should_run_first
1/2 Test #2: i_should_run_first ...   Passed0.01 sec
Start 1: i_should_run_second
2/2 Test #1: i_should_run_second ..   Passed0.01 sec

100% tests passed, 0 tests failed out of 2

Total Test time (real) =   0.02 sec

___
Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


[CMake] Using ctest

2010-11-23 Thread Cochran, Bill
Hello,

I have nearly succeeded moving a project from an autotools based system to a 
CMake/CTest/CDash system.  I must say I am impressed with CMake.  I have two 
questions though:

1)  Is it possible for CTest to use a shell script which calls cmake?  The 
project depends on a dozen TPLs installed many different ways on many different 
platforms.  These are set with variables on the command line.  So, we have 
one-line shell scripts for configuring on different platforms.  By the way, on 
my cmake test machine, 

  ctest --build-nocmake 

invokes cmake.

2)  I am having troubles getting CTest to build in parallel.  Am I supposed to 
use --build-options to pass -j8 to make?  Or, is there another way to do this?

Thanks,
Bill
___
Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


Re: [CMake] test property COST not working in cmake 2.8.3?

2010-11-23 Thread David Cole
It might be due to this commit:
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=142edf8ad4baccd991a6a8a3e5283d0b575acca2
(first released in 2.8.3)

Or this one:
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=b4d27dc041c9164d6f3ad39e192f4b7d116ca3b3
(first released in 2.8.2)

Either way, seems like a bug to me. If you explicitly specify a COST
property value, especially a negative one to induce last run status,
then it should be honored over either historical average measurement
or failed last time, so run it first this time behavior.

Zach, do you agree?


Thanks,
David


On Tue, Nov 23, 2010 at 5:36 PM, Tyler Roscoe ty...@cryptio.net wrote:
 I use set_tests_properties (... COST -500) to force my code coverage
 checks to run after all the unit tests have run. This has stopped
 working and I'm reasonably confident that the only thing that changed
 was an upgrade from cmake 2.8.0 or 2.8.1 to 2.8.3.

 I couldn't find anything in the bug tracker or in the release notes
 suggesting that COST or test properties were changed in 2.8.3.

 I'm still getting lines like this in my generated CTestTestfile.cmake:

    SET_TESTS_PROPERTIES(rs_exerciser_2dgrid PROPERTIES  COST -500 
 FAIL_REGULAR_EXPRESSION TP_EXERCISER_FAIL)

 and the FAIL_REGULAR_EXPRESSION property seems to be working just fine.


 I've included a small repro case below. This looks like a regression. Should I
 open a bug?

 Thanks,
 tyler


 [tyle...@tpb006:~/cmake-test-properties-test]$ cat CMakeLists.txt
 cmake_minimum_required(VERSION 2.8)
 project(p)
 enable_testing()

 add_test (i_should_run_second echo i should run second)
 set_tests_properties (i_should_run_second PROPERTIES COST -1)
 add_test (i_should_run_first echo i should run first)

 [tyle...@tpb006:~/cmake-test-properties-test]$ mkdir b  cd b  cmake ..
 -- The C compiler identification is GNU
 -- The CXX compiler identification is GNU
 -- Check for working C compiler: /usr/bin/gcc
 -- Check for working C compiler: /usr/bin/gcc -- works
 -- Detecting C compiler ABI info
 -- Detecting C compiler ABI info - done
 -- Check for working CXX compiler: /usr/bin/c++
 -- Check for working CXX compiler: /usr/bin/c++ -- works
 -- Detecting CXX compiler ABI info
 -- Detecting CXX compiler ABI info - done
 -- Configuring done
 -- Generating done
 -- Build files have been written to: 
 /tpb006/tylermr/cmake-test-properties-test/b

 [tyle...@tpb006:~/cmake-test-properties-test/b]$ ctest --version
 ctest version 2.8.3
 [tyle...@tpb006:~/cmake-test-properties-test/b]$ ctest
 Test project /tpb006/tylermr/cmake-test-properties-test/b
    Start 1: i_should_run_second
 1/2 Test #1: i_should_run_second ..   Passed    0.01 sec
    Start 2: i_should_run_first
 2/2 Test #2: i_should_run_first ...   Passed    0.01 sec

 100% tests passed, 0 tests failed out of 2

 Total Test time (real) =   0.04 sec

 [tyle...@tpb006:~/cmake-test-properties-test/b]$ 
 /usr/local/cmake-2.8.1-Linux-i386/bin/ctest --version
 ctest version 2.8.1
 [tyle...@tpb006:~/cmake-test-properties-test/b]$ 
 /usr/local/cmake-2.8.1-Linux-i386/bin/ctest
 Test project /tpb006/tylermr/cmake-test-properties-test/b
    Start 2: i_should_run_first
 1/2 Test #2: i_should_run_first ...   Passed    0.01 sec
    Start 1: i_should_run_second
 2/2 Test #1: i_should_run_second ..   Passed    0.01 sec

 100% tests passed, 0 tests failed out of 2

 Total Test time (real) =   0.02 sec

 ___
 Powered by www.kitware.com

 Visit other Kitware open-source projects at 
 http://www.kitware.com/opensource/opensource.html

 Please keep messages on-topic and check the CMake FAQ at: 
 http://www.cmake.org/Wiki/CMake_FAQ

 Follow this link to subscribe/unsubscribe:
 http://www.cmake.org/mailman/listinfo/cmake

___
Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


Re: [CMake] option, configure_file and ON/OFF

2010-11-23 Thread Michael Hertling
On 11/23/2010 10:30 PM, Anton Deguet wrote:
 Hello,
 
 I am trying to use a UI option to set a value used in configure_file and 
 ideally obtain a file that doesn't use ON/OFF.   Here is a CMake sample:
   option (MYLIB_HAS_WHATEVER Use whatever library OFF)
 
 In my config.h.in I have:
   #define ON 1
   #define OFF 0
   #define MYLIB_HAS_WHATEVER ${MYLIB_HAS_WHATEVER}
 
 Then in my code I can use:
   #if MYLIB_HAS_WHATEVER
   
   #endif
 
 It worked so far but there is an issue if we end up using other libraries 
 which also define ON and/or OFF.  There seems to be no way to tell CMake to 
 use 1/0 instead of ON/OFF during the configure_file.  My solution has been to 
 modify my CMake to do the following:
   option (MYLIB_HAS_WHATEVER Use whatever library OFF)
   if (MYLIB_HAS_WHATEVER)
 set(MYLIB_CONFIG_HAS_WHATEVER 1)
 
   else (MYLIB_HAS_WHATEVER)
 set(MYLIB_CONFIG_HAS_WHATEVER 0)
 
   endif (MYLIB_HAS_WHATEVER)
 
 and in the config.h.in do:
   #define MYLIB_HAS_WHATEVER ${MYLIB_CONFIG_HAS_WHATEVER}
 
 Is there a better way?

In your config.h.in, simply write:

#cmakedefine01 MYLIB_HAS_WHATEVER

With CONFIGURE_FILE(), this expands to

#define MYLIB_HAS_WHATEVER 0

or

#define MYLIB_HAS_WHATEVER 1

depending on the value of MYLIB_HAS_WHATEVER.

Regards,

Michael
___
Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


[CMake] howto re-run file(COPY signature ?

2010-11-23 Thread Dominique Belhachemi
Hello,

I am using the following command in my CMakeLists.txt file to copy a
directory with all sub-directories from the source tree to a directory
in the binary tree.

file(COPY ${SRCDIR}
  DESTINATION ${CMAKE_BINARY_DIR}/${DSTDIR}/
  PATTERN .svn EXCLUDE
)

After adding this line to CMakeLists.txt and typing 'make' the command
is working like expected. But after adding a new file to ${SRCDIR} and
typing 'make' again, the new file doesn't get copied. I have to do a
'touch CMakeLists.txt' first.

Is there a way to enforce the execution?

Thanks
Dominique

___
Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


[Cmake-commits] CMake branch, master, updated. v2.8.3-84-g8828103

2010-11-23 Thread David Cole
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, master has been updated
   via  88281035bd856ef0d5cd6abb1079b24dd8aa6124 (commit)
   via  35b91ac5c0d781bcea5d013bcd62fa11c6841d6f (commit)
  from  40cb8a2373d1805e10ce1b0a4702bfb3365ad994 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=88281035bd856ef0d5cd6abb1079b24dd8aa6124
commit 88281035bd856ef0d5cd6abb1079b24dd8aa6124
Merge: 40cb8a2 35b91ac
Author: David Cole david.c...@kitware.com
AuthorDate: Tue Nov 23 16:11:15 2010 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Tue Nov 23 16:11:15 2010 -0500

Merge topic 'moc-includes-regex'

35b91ac Fix regex for moc includes when looking for frameworks.


---

Summary of changes:
 Modules/Qt4Macros.cmake |8 
 1 files changed, 4 insertions(+), 4 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v2.8.3-92-gfa882bb

2010-11-23 Thread David Cole
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, master has been updated
   via  fa882bb570337686c20041d4a6cf89b42e4e1810 (commit)
   via  e0b60166d4c8526db0cf2e8b1eae49ba8ed45ff6 (commit)
   via  d25c2eb0c0a942d60826e6263d96a2ba59b97b92 (commit)
   via  e614e9b3d7387b5aa1611f5547744e84b3a0645f (commit)
   via  79dd9becadd39b518a90bbe4c86cd17a57ab1d54 (commit)
   via  ffeca06a93eca70ef7505ac087cbb246e5191ed2 (commit)
   via  7b337ac8e20437bf134319bf3131505f69892447 (commit)
   via  e1fc9b902ac737c98ecaf236568d3e685ea3dce1 (commit)
  from  88281035bd856ef0d5cd6abb1079b24dd8aa6124 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=fa882bb570337686c20041d4a6cf89b42e4e1810
commit fa882bb570337686c20041d4a6cf89b42e4e1810
Merge: 8828103 e0b6016
Author: David Cole david.c...@kitware.com
AuthorDate: Tue Nov 23 16:11:22 2010 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Tue Nov 23 16:11:22 2010 -0500

Merge topic 'AddASM_NASMSupport'

e0b6016 Some more fixes for nasm support, from Etienne (#10069)
d25c2eb Use CMAKE_ASM_NASM_FLAGS for nasm instead of FLAGS
e614e9b Add support for yasm, a nasm compatible assembler
79dd9be We already have 2010, fix copyright year.
ffeca06 Add missing copyright headers
7b337ac Improve misleading comments.
e1fc9b9 Add support for nasm assembler, patch by Peter Collingbourne (see 
#10069)


---

Summary of changes:
 Modules/CMakeASM_NASMInformation.cmake |   46 
 cmake = CMakeDetermineASM_NASMCompiler.cmake} |   18 
 Modules/CMakeTestASM-ATTCompiler.cmake |8 ++--
 Modules/CMakeTestASMCompiler.cmake |9 ++--
 Modules/CMakeTestASM_MASMCompiler.cmake|8 ++--
 ...piler.cmake = CMakeTestASM_NASMCompiler.cmake} |   12 +++---
 6 files changed, 74 insertions(+), 27 deletions(-)
 create mode 100644 Modules/CMakeASM_NASMInformation.cmake
 copy Modules/{CMakeDetermineASM_MASMCompiler.cmake = 
CMakeDetermineASM_NASMCompiler.cmake} (60%)
 copy Modules/{CMakeTestASM-ATTCompiler.cmake = 
CMakeTestASM_NASMCompiler.cmake} (69%)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v2.8.3-102-g651120b

2010-11-23 Thread David Cole
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, master has been updated
   via  651120b7afa90268b2317b4ad8eaa98150d3ccce (commit)
   via  78c86f454272a2ac417ad6a89e4c7ed7e4975adb (commit)
   via  5ea1e4cb36d813bcb1377637779a54f18411763b (commit)
   via  2a5790a080d86c63daf3d2c17d533c919cbef582 (commit)
   via  7ba2d365858d259572b22ab35ea6c709ba1514ea (commit)
   via  84ce612c65520c273aa3b1d2efd2f8f4de7d3867 (commit)
   via  a60b09927d4c29756c428d4c38f5ee2810a8f66e (commit)
   via  487bd571d56134b15b1060e1921a7e16711f12e6 (commit)
   via  de2b2bf9efe88bbde1b66857d00538084cc6c591 (commit)
   via  f7d56df39eb4567c187e429a7162a1204f8d2d1b (commit)
  from  fa882bb570337686c20041d4a6cf89b42e4e1810 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=651120b7afa90268b2317b4ad8eaa98150d3ccce
commit 651120b7afa90268b2317b4ad8eaa98150d3ccce
Merge: fa882bb 78c86f4
Author: David Cole david.c...@kitware.com
AuthorDate: Tue Nov 23 16:11:26 2010 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Tue Nov 23 16:11:26 2010 -0500

Merge topic 'ImprovedDotSupport2'

78c86f4 Exclude targets from the graphviz file based on a regex
5ea1e4c Collect targets and libs on demand instead of in the ctor
2a5790a Use std::cout instead of fprintf
7ba2d36 Enable/disable generating graphs depending on the target type
84ce612 Move the code for generating dot-files into separate class 
cmGraphVizWriter
a60b099 Generate separate dot files for each target, and a big one with 
everything.
487bd57 Properly insert all targets, also those which don't link to 
anything.
de2b2bf Move the code for collecting targets and libraries into separate 
functions
f7d56df Remove trailing whitespace and minor formatting changes for the 
dot-code


---

Summary of changes:
 Source/CMakeLists.txt   |6 +-
 Source/cmGraphVizWriter.cxx |  435 +++
 Source/cmGraphVizWriter.h   |   84 +
 Source/cmake.cxx|  385 --
 Source/cmake.h  |   76 
 5 files changed, 642 insertions(+), 344 deletions(-)
 create mode 100644 Source/cmGraphVizWriter.cxx
 create mode 100644 Source/cmGraphVizWriter.h


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v2.8.3-105-g525b528

2010-11-23 Thread David Cole
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, master has been updated
   via  525b528625ad489c75faa79d3113b96cfa41a96a (commit)
   via  66e86b4770dcda3b5e79776c4cda6e60646189f1 (commit)
   via  2c84d169b36b1b8713517a8d8799b82dbf59725a (commit)
  from  651120b7afa90268b2317b4ad8eaa98150d3ccce (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=525b528625ad489c75faa79d3113b96cfa41a96a
commit 525b528625ad489c75faa79d3113b96cfa41a96a
Merge: 651120b 66e86b4
Author: David Cole david.c...@kitware.com
AuthorDate: Tue Nov 23 16:11:33 2010 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Tue Nov 23 16:11:33 2010 -0500

Merge topic 'CPackRPM-ComponentSupport'

66e86b4 CPack  fix kwstyle breakage and make CPackRPM backward compatible
2c84d16 CPackRPM  add basic component support to CPackRPM


---

Summary of changes:
 Modules/CPackRPM.cmake   |   37 -
 Source/CPack/cmCPackArchiveGenerator.cxx |   65 ++-
 Source/CPack/cmCPackArchiveGenerator.h   |4 +-
 Source/CPack/cmCPackGenerator.cxx|   86 -
 Source/CPack/cmCPackGenerator.h  |   25 +
 Source/CPack/cmCPackRPMGenerator.cxx |   77 +-
 Source/CPack/cmCPackRPMGenerator.h   |1 +
 7 files changed, 214 insertions(+), 81 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v2.8.3-109-gfcea494

2010-11-23 Thread David Cole
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, master has been updated
   via  fcea494787f9a001fef06cc4710dd24c233c7980 (commit)
   via  e3dfbf62fcd54f582057fcec7a7989ac73712e55 (commit)
  from  584612595d78c4450b679f5d3a34eda7164b67e1 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=fcea494787f9a001fef06cc4710dd24c233c7980
commit fcea494787f9a001fef06cc4710dd24c233c7980
Merge: 5846125 e3dfbf6
Author: David Cole david.c...@kitware.com
AuthorDate: Tue Nov 23 16:11:40 2010 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Tue Nov 23 16:11:40 2010 -0500

Merge topic 'IncludeCMakeDetermineCompilerIdInDetermineASMCompiler'

e3dfbf6 Include CMakeDetermineCompilerId in CMakeDetermineASMCompiler.cmake 
(#11467)


---

Summary of changes:
 Modules/CMakeDetermineASMCompiler.cmake |1 +
 1 files changed, 1 insertions(+), 0 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v2.8.3-111-g0a5600a

2010-11-23 Thread David Cole
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, master has been updated
   via  0a5600af2d8467f83eb2f5559c10e5d7776e2ba8 (commit)
   via  5fe3ac86ee1702d957621c2054507eed2c393c6f (commit)
  from  fcea494787f9a001fef06cc4710dd24c233c7980 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=0a5600af2d8467f83eb2f5559c10e5d7776e2ba8
commit 0a5600af2d8467f83eb2f5559c10e5d7776e2ba8
Merge: fcea494 5fe3ac8
Author: David Cole david.c...@kitware.com
AuthorDate: Tue Nov 23 16:11:43 2010 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Tue Nov 23 16:11:43 2010 -0500

Merge topic 'link-library-parse-regex'

5fe3ac8 Prefer non-empty prefixes when matching lib names (#11468)


---

Summary of changes:
 Source/cmComputeLinkInformation.cxx |2 +-
 1 files changed, 1 insertions(+), 1 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v2.8.3-113-gc985676

2010-11-23 Thread David Cole
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, master has been updated
   via  c985676a96394fbe1de728ba1bafcf845d511048 (commit)
   via  a44a05cd9de17f3dec7dbcae405e4f455176bd3a (commit)
  from  0a5600af2d8467f83eb2f5559c10e5d7776e2ba8 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=c985676a96394fbe1de728ba1bafcf845d511048
commit c985676a96394fbe1de728ba1bafcf845d511048
Merge: 0a5600a a44a05c
Author: David Cole david.c...@kitware.com
AuthorDate: Tue Nov 23 16:11:46 2010 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Tue Nov 23 16:11:46 2010 -0500

Merge topic '11430'

a44a05c 11430: FindBullet doesn't find header files installed by Bullet = 
2.77


---

Summary of changes:
 Modules/FindBullet.cmake |5 +++--
 1 files changed, 3 insertions(+), 2 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v2.8.3-115-gf04bc9f

2010-11-23 Thread David Cole
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, master has been updated
   via  f04bc9fe93e96485a7684fc12a86cad50084ba69 (commit)
   via  0263d8dffe9d5cf994f72d517ef2e8374ac8b2a2 (commit)
  from  c985676a96394fbe1de728ba1bafcf845d511048 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=f04bc9fe93e96485a7684fc12a86cad50084ba69
commit f04bc9fe93e96485a7684fc12a86cad50084ba69
Merge: c985676 0263d8d
Author: David Cole david.c...@kitware.com
AuthorDate: Tue Nov 23 16:11:50 2010 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Tue Nov 23 16:11:50 2010 -0500

Merge topic '11384'

0263d8d 11384: FindCxxTest now includes test code in VS project


---

Summary of changes:
 Modules/FindCxxTest.cmake |7 ++-
 1 files changed, 6 insertions(+), 1 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v2.8.3-121-ga30a83b

2010-11-23 Thread David Cole
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, master has been updated
   via  a30a83bc1d1150b00d26ca858127406341a481bd (commit)
   via  e01cce28694201342adc97825982ed66fc52af65 (commit)
   via  bc7395c096be40f8a0fecbab4aa7539c05898ef2 (commit)
   via  fd614e60b51e11ac8a99c19d541be9a8e5c141dc (commit)
   via  605f4bc0978fd3c84bc06875aef500e62b0f41c7 (commit)
   via  82596fcffcdf3e536fb0def67f6d4d1d1a3e5207 (commit)
  from  f04bc9fe93e96485a7684fc12a86cad50084ba69 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=a30a83bc1d1150b00d26ca858127406341a481bd
commit a30a83bc1d1150b00d26ca858127406341a481bd
Merge: f04bc9f e01cce2
Author: David Cole david.c...@kitware.com
AuthorDate: Tue Nov 23 16:11:57 2010 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Tue Nov 23 16:11:57 2010 -0500

Merge topic 'imported-target-dependencies'

e01cce2 Allow add_dependencies() on imported targets (#10395)
bc7395c Merge branch 'vs-target-dependencies' into 
imported-target-dependencies
fd614e6 Use modern global dependency graph for VS  8 deps
605f4bc Record edge type in global dependency graph
82596fc Merge branch 'vs8-direct-depends' into vs-target-dependencies


---

Summary of changes:
 Source/cmAddDependenciesCommand.cxx|6 +-
 Source/cmAddDependenciesCommand.h  |2 +
 Source/cmComputeTargetDepends.cxx  |   69 ++
 Source/cmComputeTargetDepends.h|4 +-
 Source/cmGlobalGenerator.h |3 +-
 Source/cmGlobalVisualStudioGenerator.cxx   |  204 ++-
 Source/cmGlobalVisualStudioGenerator.h |   25 +++-
 Source/cmTargetDepend.h|   48 +++
 Tests/ExportImport/Import/A/CMakeLists.txt |   16 ++
 Tests/ExportImport/Import/A/imp_lib1.c |2 +-
 10 files changed, 270 insertions(+), 109 deletions(-)
 create mode 100644 Source/cmTargetDepend.h


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v2.8.3-123-g22c1386

2010-11-23 Thread David Cole
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, master has been updated
   via  22c138646a812bb5bd95c65928dd89248761a470 (commit)
   via  eda7841fd2de59b1dd055c4996276a2137d2 (commit)
  from  a30a83bc1d1150b00d26ca858127406341a481bd (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=22c138646a812bb5bd95c65928dd89248761a470
commit 22c138646a812bb5bd95c65928dd89248761a470
Merge: a30a83b eda7841
Author: David Cole david.c...@kitware.com
AuthorDate: Tue Nov 23 16:12:18 2010 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Tue Nov 23 16:12:18 2010 -0500

Merge topic 'pgi-mac'

eda7841 Pass Mac linker flag through PGI compiler using -Wl,


---

Summary of changes:
 Modules/Platform/Darwin.cmake |8 
 1 files changed, 4 insertions(+), 4 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v2.8.3-702-g5b1b47d

2010-11-23 Thread Clinton Stimpson
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  5b1b47d703f88d8a65aab4a1a196b727b9eb0f67 (commit)
   via  bd66cc9d39a1ce1f81e44fca95142ee3842b6501 (commit)
  from  1c597e968dfda90da7460cae33b9e5fbdb8a5e72 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=5b1b47d703f88d8a65aab4a1a196b727b9eb0f67
commit 5b1b47d703f88d8a65aab4a1a196b727b9eb0f67
Merge: 1c597e9 bd66cc9
Author: Clinton Stimpson clin...@elemtech.com
AuthorDate: Tue Nov 23 18:02:44 2010 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Tue Nov 23 18:02:44 2010 -0500

Merge topic 'qt4-deps-tiff-jpeg-mng' into next

bd66cc9 Fix build issues cross compiling with static Qt.


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=bd66cc9d39a1ce1f81e44fca95142ee3842b6501
commit bd66cc9d39a1ce1f81e44fca95142ee3842b6501
Author: Clinton Stimpson clin...@elemtech.com
AuthorDate: Tue Nov 23 16:01:43 2010 -0700
Commit: Clinton Stimpson clin...@elemtech.com
CommitDate: Tue Nov 23 16:01:43 2010 -0700

Fix build issues cross compiling with static Qt.

Also fix case where system jpeg, png, tiff libs are used.

diff --git a/Modules/Qt4ConfigDependentSettings.cmake 
b/Modules/Qt4ConfigDependentSettings.cmake
index bfb50de..10af3bc 100644
--- a/Modules/Qt4ConfigDependentSettings.cmake
+++ b/Modules/Qt4ConfigDependentSettings.cmake
@@ -35,10 +35,10 @@ SET(QT_QTHELP_LIB_DEPENDENCIES ${QT_QTCLUCENE_LIBRARY})
 
 
 IF(Q_WS_WIN)
-  # On Windows, qconfig.pri has static for static library builds
-  IF(QT_CONFIG MATCHES static)
+  # On Windows, qconfig.pri has shared for shared library builds
+  IF(NOT QT_CONFIG MATCHES shared)
 SET(QT_IS_STATIC 1)
-  ENDIF(QT_CONFIG MATCHES static)
+  ENDIF(NOT QT_CONFIG MATCHES shared)
 ELSE(Q_WS_WIN)
   # On other platforms, check file extension to know if its static
   IF(QT_QTCORE_LIBRARY_RELEASE)
@@ -75,6 +75,23 @@ IF(QT_QCONFIG MATCHES system-png)
   SET(QT_QTGUI_LIB_DEPENDENCIES ${QT_QTGUI_LIB_DEPENDENCIES} ${PNG_LIBRARY})
 ENDIF(QT_QCONFIG MATCHES system-png)
 
+## system jpeg
+IF(QT_QCONFIG MATCHES system-jpeg)
+  find_package(JPEG)
+  SET(QT_QTGUI_LIB_DEPENDENCIES ${QT_QTGUI_LIB_DEPENDENCIES} ${JPEG_LIBRARIES})
+ENDIF(QT_QCONFIG MATCHES system-jpeg)
+
+## system tiff
+IF(QT_QCONFIG MATCHES system-tiff)
+  find_package(TIFF)
+  SET(QT_QTGUI_LIB_DEPENDENCIES ${QT_QTGUI_LIB_DEPENDENCIES} ${TIFF_LIBRARIES})
+ENDIF(QT_QCONFIG MATCHES system-tiff)
+
+## system mng
+IF(QT_QCONFIG MATCHES system-mng)
+  find_library(MNG_LIBRARY NAMES mng)
+  SET(QT_QTGUI_LIB_DEPENDENCIES ${QT_QTGUI_LIB_DEPENDENCIES} ${MNG_LIBRARY})
+ENDIF(QT_QCONFIG MATCHES system-mng)
 
 # for X11, get X11 library directory
 IF(Q_WS_X11)

---

Summary of changes:
 Modules/Qt4ConfigDependentSettings.cmake |   23 ---
 1 files changed, 20 insertions(+), 3 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits